check is a generic S3 method for classes inheriting
from item. It is a logical method checking if the item is well defined
with respect to a risk (i.e. that all information necessary for valuating
the item is available).
# S3 method for health
check(object, market.risk, health.risk, ...)S3 object of class health.
S3 object of class marketRisk created using the constructor
marketRisk.
S3 object of class healthRisk, created using the constructor
healthRisk.
additional arguments.
a logical value, is the health item consistent with the marketRisk and the healthRisk?